/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsRemoveInterceptor.java 940 2006-07-26 09:05:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.container.session.stateful.interceptors;

import org.objectweb.easybeans.api.EasyBeansInvocationContext;
import org.objectweb.easybeans.api.Factory;
import org.objectweb.easybeans.api.bean.EasyBeansSFSB;
import org.objectweb.easybeans.api.pool.Pool;
import org.objectweb.easybeans.api.pool.PoolException;
import org.objectweb.easybeans.container.session.stateful.StatefulSessionFactory;


/**
 * Defines a method that discard the bean found in the invocation context.
 * @author Florent Benoit
 */
public abstract class AbsRemoveInterceptor {

    /**
     * Remove from the factory's pool the bean found in the current invocation context.
     * @param invocationContext the context of the current invocation
     * @throws PoolException if removal is failing
     */
    protected void remove(final EasyBeansInvocationContext invocationContext) throws PoolException {
        // Gets the factory
        Factory factory = invocationContext.getFactory();

        // factory is a stateful factory.
        StatefulSessionFactory statefulFactory = (StatefulSessionFactory) factory;

        // get pool
        Pool<EasyBeansSFSB, Long> pool = statefulFactory.getPool();

        // Bean is a stateful bean
        EasyBeansSFSB bean = (EasyBeansSFSB) invocationContext.getTarget();

        // discard instance
        pool.discard(bean);
    }
}
